@@ -8,7 +8,7 @@
 #   The GNU Lesser General Public License, Version 2.1, February 1999
 #
 package Config::Model::Instance;
-$Config::Model::Instance::VERSION = '2.115';
+$Config::Model::Instance::VERSION = '2.116';
 #use Scalar::Util qw(weaken) ;
 use strict;
 
@@ -238,13 +238,13 @@ has [qw/name application backend backend_arg backup/] => (
 
 has 'root_dir' => (
     is => 'bare',
-    isa => 'Str',
-    default => ''
+    isa => 'Maybe[Str]',
 );
 
 sub root_dir {
     my $self = shift;
-    my $d = $self->{root_dir};
+    my $d = $self->{root_dir} // '';
+    # add trailing '/' if it's missing
     return $d && $d !~ m!/$! ? "$d/" : $d;
 }
 
@@ -661,7 +661,7 @@ Config::Model::Instance - Instance of configuration tree
 
 =head1 VERSION
 
-version 2.115
+version 2.116
 
 =head1 SYNOPSIS
 
